% Jim Wang
% 9/9/08
%
% f_I_curve.m
%
% plots firing rate versus applied current 
% produces figure 1 and figure 2 in the Shriki paper
%
% I_app = applied current (A/cm^2)
% dt = time step (ms)
% T = total time of simulation (ms)
% Example: f_I_curve(0:.1:5,0.01,500)

function f_I_curve(I_app,dt,T)

close all
v0 = f_I_curve_initial_condition;   % initial condition

% figure 1 in the Shriki paper
% plotting f versus I and varying tau_a and gbar_A
Tau_A = [0 0 20];   % ms
Gbar_A = [0 20 20]; % mS/cm^2  
g_L = 0.05;     % mS/cm^2
spikefreq = zeros(length(Tau_A),length(I_app)); % initializing
for i = 1:length(Tau_A)
    tau_A = Tau_A(i); gbar_A = Gbar_A(i);
    for j = 1:length(I_app)
        spikefreq(i,j) = heas(I_app(j),dt,T,v0,tau_A,gbar_A,g_L,0); % returns spike frequency
    end
end
figure(4)
set(gca,'FontSize',18)
plot(I_app,spikefreq(1,:)*1000,'r',I_app,spikefreq(2,:)*1000,'b',I_app,spikefreq(3,:)*1000,'g')
xlabel('I_{app} (A/cm^2)')
ylabel('Firing Rate (spike/sec)')
legend('tau_A = 0; gbar_A = 0','tau_A = 0; gbar_A = 20','tau_A = 20; gbar_A = 20','Location','NorthWest')

% figure 2 in the Shriki paper
% plotting f versus I and varying g_L
gbar_A = 20;    % mS/cm^2
tau_A = 20;     % msec
g_L = [0.05 0.1 0.15 0.2];   % mS/cm^2
spikefreq = zeros(length(g_L),length(I_app));   % initializing
for i = 1:length(g_L)
    for j = 1:length(I_app)
        spikefreq(i,j) = heas(I_app(j),dt,T,v0,tau_A,gbar_A,g_L(i),0);
    end
end
figure(5)
set(gca,'FontSize',18)
plot(I_app,spikefreq*1000)
xlabel('I_{app} (A/cm^2)')
ylabel('Firing Rate (spike/sec)')
legend('g_L = 0.05','g_L = 0.1','g_L = 0.15','g_L = 0.2','Location','NorthWest')
