% Jim Wang
% 9/9/08
%
% Equation: Cm*(dV/dt) = I_active(V)
% 
% numerically solve for initial conditions. Initially, cell is at rest, so
% dV/dt = 0, thus, we want to solve for V in the equation I_active(V) = 0.
% This V is the resting membrane potential.
%
% Example: f_I_curve_initial_condition

function solution = f_I_curve_initial_condition

gbar_k = 40;    % mS/cm^2
g_L = 0.05;     % mS/cm^2
gbar_A = 20;    % mS/cm^2
E_k = -80;      % mV
E_L = -65;      % mV
phi = 0.1;

V = linspace(-100,50,100);  % tests these V (mV)

alpha_m = -0.1*(V+30)./(exp(-0.1*(V+30))-1);
beta_m = 4*exp(-(V+55)/18);

alpha_h = 0.07*exp(-(V+44)/20);
beta_h = 1./(exp(-0.1*(V+14))+1);

alpha_n = -0.01*(V+34)./(exp(-0.1*(V+34))-1);
beta_n = 0.125*exp(-(V+44)/80);
    
a_inf = 1./(exp(-(V+50)/20)+1);
b_inf = 1./(exp((V+80)/6)+1);
m_inf = alpha_m./(alpha_m+beta_m);
h_inf = alpha_h./(alpha_h+beta_h);   
n_inf = alpha_n./(alpha_n+beta_n);

tau_h = phi./(alpha_h+beta_h);
tau_n = phi./(alpha_n+beta_n);

ntemp = n_inf.^4;
atemp = a_inf.^3;
mtemp = m_inf.^3;
a = g_L*(E_L-V)+g_L*mtemp.*h_inf.*(E_L-V)+gbar_k*ntemp.*(E_k-V)+gbar_A*atemp.*b_inf.*(E_k-V);   % active current

figure(1)
subplot(2,3,1)
plot(V,m_inf,'r')
xlabel('V (mV)')
ylabel('Blue = \tau/\tau_{max}, red = w_\infty')
title('m')
subplot(2,3,2)
plot(V,h_inf,'r',V,tau_h/max(tau_h),'b')
xlabel('V (mV)')
title('h')
subplot(2,3,3)
plot(V,n_inf,'r',V,tau_n/max(tau_n),'b')
xlabel('V (mV)')
title('n')
subplot(2,3,4)
plot(V,a_inf,'r')
xlabel('V (mV)')
title('a')
subplot(2,3,5)
plot(V,b_inf,'r')
xlabel('V (mV)')
title('b')
subplot(2,3,6)
plot(V(1:34),a(1:34),'b')
xlabel('V (mV)')
ylabel('Active Current (A/cm^2)')

guess1 = find(V>-85,1,'first'); % left bound guess for bisection
guess2 = find(V>-60,1,'first'); % right bound guess for bisection
solution = taper(V,a,guess1,guess2,1e-2);   % solves active current = 0 for V through bisection