% Jim Wang
% 9/9/08
%
% figure 2 inset
% plots leak gating variable versus threshold current
%
% Example: gL_vs_Ic

clear all
close all
tic

gbar_A = 20;    % mS/cm^2
tau_A = 20;     % msec
g_L = linspace(0.05,0.2,5);   % varies leak conductance (mS/cm^2)
dt = 0.01;      % ms
T = 350;        % ms

Idt = .02;   % rate at which I increments
v0 = f_I_curve_initial_condition;   % initial condition

Ic = zeros(1,length(g_L)); % initializing threshold current vector

for i = 1:length(g_L)
    I = 0.5;    % (A/cm^2)
    spikefreq = heas(I,dt,T,v0,tau_A,gbar_A,g_L(i),0);  % firing rate
    j = 1;  % counter to avoid infinite loop
    while spikefreq == 0 && j<=1.5/dt % if no firing
        I = I+Idt;  % increase current
        spikefreq = heas(I,dt,T,v0,tau_A,gbar_A,g_L(i),0);  % update firing rate
        j = j+1;    % undate counter
    end
    Ic(i) = I;  % updates threshold current vector
    if j > 1.5/dt
        disp('quit infinite loop')
    end
end
figure
plot(g_L,Ic,'r')
set(gca,'FontSize',18)
axis([.05 .2 .5 2.2])
xlabel('g_L (mS/cm^2)')
ylabel('I_c (A/cm^2)')
toc